==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPaneDragOverEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebPaneDragOverEventArgsDetailDescription = /*@__PURE__*/ (() => {
    class WebPaneDragOverEventArgsDetailDescription extends Description {
        constructor() {
            super();
            this.h = null;
            this.f = null;
            this.j = null;
            this.m = false;
        }
        get_type() {
            return "WebPaneDragOverEventArgsDetail";
        }
        get type() {
            return this.get_type();
        }
        get sourcePane() {
            return this.h;
        }
        set sourcePane(a) {
            this.h = a;
            this.e("SourcePane");
        }
        get panes() {
            return this.f;
        }
        set panes(a) {
            this.f = a;
            this.e("Panes");
        }
        get action() {
            return this.j;
        }
        set action(a) {
            this.j = a;
            this.e("Action");
        }
        get isValid() {
            return this.m;
        }
        set isValid(a) {
            this.m = a;
            this.e("IsValid");
        }
    }
    WebPaneDragOverEventArgsDetailDescription.$t = /*@__PURE__*/ markType(WebPaneDragOverEventArgsDetailDescription, 'WebPaneDragOverEventArgsDetailDescription', Description.$);
    WebPaneDragOverEventArgsDetailDescription.__marshalByValue = true;
    WebPaneDragOverEventArgsDetailDescription.__marshalByValueAlias = "PaneDragOverEventArgsDetail";
    return WebPaneDragOverEventArgsDetailDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebPaneDragOverEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebPaneDragOverEventArgsDetailDescription = /*@__PURE__*/ (() => {
    class WebPaneDragOverEventArgsDetailDescription extends Description {
        get_type() {
            return "WebPaneDragOverEventArgsDetail";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.j = null;
            this.h = null;
            this.l = null;
            this.o = false;
        }
        get sourcePane() {
            return this.j;
        }
        set sourcePane(a) {
            this.j = a;
            this.g("SourcePane");
        }
        get panes() {
            return this.h;
        }
        set panes(a) {
            this.h = a;
            this.g("Panes");
        }
        get action() {
            return this.l;
        }
        set action(a) {
            this.l = a;
            this.g("Action");
        }
        get isValid() {
            return this.o;
        }
        set isValid(a) {
            this.o = a;
            this.g("IsValid");
        }
    }
    WebPaneDragOverEventArgsDetailDescription.$t = /*@__PURE__*/ markType(WebPaneDragOverEventArgsDetailDescription, 'WebPaneDragOverEventArgsDetailDescription', Description.$);
    WebPaneDragOverEventArgsDetailDescription.__marshalByValue = true;
    WebPaneDragOverEventArgsDetailDescription.__marshalByValueAlias = "PaneDragOverEventArgsDetail";
    return WebPaneDragOverEventArgsDetailDescription;
})();
